@@ -132,8 +132,15 @@ void AutoStartPage::addButton_clicked()
     bool success = false;
     while (!success && edit.exec() == QDialog::Accepted)
     {
+        const auto trimmedName = edit.name().trimmed();
+        const auto trimmedCommand = edit.command().trimmed();
         QModelIndex index = ui->autoStartView->selectionModel()->currentIndex();
-        XdgDesktopFile file(XdgDesktopFile::ApplicationType, edit.name(), edit.command());
+        if (trimmedName.isEmpty() || trimmedCommand.isEmpty() )
+        {
+            QMessageBox::critical(this, tr("Error"), tr("Please provide Name and Command"));
+            continue;
+        }
+        XdgDesktopFile file(XdgDesktopFile::ApplicationType, trimmedName, trimmedCommand);
         if (edit.needTray())
             file.setValue(QL1S("X-LXQt-Need-Tray"), true);
         if (mXdgAutoStartModel->setEntry(index, file))
@@ -148,16 +155,27 @@ void AutoStartPage::editButton_clicked()
     QModelIndex index = ui->autoStartView->selectionModel()->currentIndex();
     XdgDesktopFile file = mXdgAutoStartModel->desktopFile(index);
     AutoStartEdit edit(file.name(), file.value(QL1S("Exec")).toString(), file.contains(QL1S("X-LXQt-Need-Tray")));
-    if (edit.exec() == QDialog::Accepted)
+    bool success = false;
+    while (!success && edit.exec() == QDialog::Accepted)
     {
-        file.setLocalizedValue(QL1S("Name"), edit.name());
-        file.setValue(QL1S("Exec"), edit.command());
+        const auto trimmedName = edit.name().trimmed();
+        const auto trimmedCommand = edit.command().trimmed();
+        if (trimmedName.isEmpty() || trimmedCommand.isEmpty() )
+        {
+            QMessageBox::critical(this, tr("Error"), tr("Please provide Name and Command"));
+            continue;
+        }
+        file.setLocalizedValue(QL1S("Name"), trimmedName);
+        file.setValue(QL1S("Exec"), trimmedCommand);
         if (edit.needTray())
             file.setValue(QL1S("X-LXQt-Need-Tray"), true);
         else
             file.removeEntry(QL1S("X-LXQt-Need-Tray"));
 
-        mXdgAutoStartModel->setEntry(index, file, true);
+        if (mXdgAutoStartModel->setEntry(index, file, true))
+            success = true;
+        else
+            QMessageBox::critical(this, tr("Error"), tr("File '%1' already exists!").arg(file.fileName()));
     }
 }
 
