@@ -80,12 +80,22 @@
         <translation>Aplikazioaren autoabioa</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="142"/>
+        <location filename="../autostartpage.cpp" line="138"/>
+        <location filename="../autostartpage.cpp" line="147"/>
+        <location filename="../autostartpage.cpp" line="161"/>
+        <location filename="../autostartpage.cpp" line="174"/>
         <source>Error</source>
         <translation>Errorea</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="142"/>
+        <location filename="../autostartpage.cpp" line="138"/>
+        <location filename="../autostartpage.cpp" line="161"/>
+        <source>Please provide Name and Command</source>
+        <translation>Mesedez, eman izena eta komandoa</translation>
+    </message>
+    <message>
+        <location filename="../autostartpage.cpp" line="147"/>
+        <location filename="../autostartpage.cpp" line="174"/>
         <source>File &apos;%1&apos; already exists!</source>
         <translation>&apos;%1&apos; fitxategia dagoeneko existitzen da!</translation>
     </message>
