@@ -80,12 +80,22 @@
         <translation>アプリケーションの自動起動</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="142"/>
+        <location filename="../autostartpage.cpp" line="138"/>
+        <location filename="../autostartpage.cpp" line="147"/>
+        <location filename="../autostartpage.cpp" line="161"/>
+        <location filename="../autostartpage.cpp" line="174"/>
         <source>Error</source>
         <translation>エラー</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="142"/>
+        <location filename="../autostartpage.cpp" line="138"/>
+        <location filename="../autostartpage.cpp" line="161"/>
+        <source>Please provide Name and Command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../autostartpage.cpp" line="147"/>
+        <location filename="../autostartpage.cpp" line="174"/>
         <source>File &apos;%1&apos; already exists!</source>
         <translation>ファイル &apos;%1&apos; が既に存在しています！</translation>
     </message>
