@@ -32,7 +32,6 @@
 #include <QGuiApplication>
 #include "log.h"
 
-#include <QX11Info>
 // XKB, this should be disabled in Wayland?
 #include <X11/XKBlib.h>
 
@@ -180,7 +179,7 @@ void SessionApplication::setxkbmap(QString layout, QString variant, QString mode
     }
   }
   if(!options.isEmpty()) {
-    for(const QString& option : qAsConst(options)) {
+    for(const QString& option : std::as_const(options)) {
       args << QStringLiteral("-option");
       args << option;
     }
@@ -192,23 +191,27 @@ void SessionApplication::setxkbmap(QString layout, QString variant, QString mode
 
 void SessionApplication::loadKeyboardSettings(LXQt::Settings& settings)
 {
-  qCDebug(SESSION) << settings.fileName();
+    qCDebug(SESSION) << settings.fileName();
     settings.beginGroup(QSL("Keyboard"));
     XKeyboardControl values;
     /* Keyboard settings */
     unsigned int delay = 0;
     unsigned int interval = 0;
-    if(XkbGetAutoRepeatRate(QX11Info::display(), XkbUseCoreKbd, (unsigned int*) &delay, (unsigned int*) &interval))
-    {
-        delay = settings.value(QSL("delay"), delay).toUInt();
-        interval = settings.value(QSL("interval"), interval).toUInt();
-        XkbSetAutoRepeatRate(QX11Info::display(), XkbUseCoreKbd, delay, interval);
-    }
+    if (auto x11NativeInterface = qGuiApp->nativeInterface<QNativeInterface::QX11Application>()) {
+        if (Display* dpy = x11NativeInterface->display()) {
+            if(XkbGetAutoRepeatRate(dpy, XkbUseCoreKbd, (unsigned int*) &delay, (unsigned int*) &interval))
+            {
+                delay = settings.value(QSL("delay"), delay).toUInt();
+                interval = settings.value(QSL("interval"), interval).toUInt();
+                XkbSetAutoRepeatRate(dpy, XkbUseCoreKbd, delay, interval);
+            }
 
-    // turn on/off keyboard beep
-    bool beep = settings.value(QSL("beep")).toBool();
-    values.bell_percent = beep ? -1 : 0;
-    XChangeKeyboardControl(QX11Info::display(), KBBellPercent, &values);
+            // turn on/off keyboard beep
+            bool beep = settings.value(QSL("beep")).toBool();
+            values.bell_percent = beep ? -1 : 0;
+            XChangeKeyboardControl(dpy, KBBellPercent, &values);
+        }
+    }
 
     // turn on numlock as needed
     if(settings.value(QSL("numlock")).toBool())
@@ -250,8 +253,13 @@ void SessionApplication::loadMouseSettings(LXQt::Settings& settings)
     // other mouse settings
     int accel_factor = settings.value(QSL("accel_factor")).toInt();
     int accel_threshold = settings.value(QSL("accel_threshold")).toInt();
-    if(accel_factor || accel_threshold)
-        XChangePointerControl(QX11Info::display(), accel_factor != 0, accel_threshold != 0, accel_factor, 10, accel_threshold);
+    if(accel_factor || accel_threshold) {
+        if (auto x11NativeInterface = qGuiApp->nativeInterface<QNativeInterface::QX11Application>()) {
+            if (Display* dpy = x11NativeInterface->display()) {
+                XChangePointerControl(dpy, accel_factor != 0, accel_threshold != 0, accel_factor, 10, accel_threshold);
+            }
+        }
+    }
 
     // left handed mouse?
     bool left_handed = settings.value(QSL("left_handed"), false).toBool();
@@ -308,40 +316,44 @@ void SessionApplication::setLeftHandedMouse(bool mouse_left_handed)
     int i = 0;
     int idx_1 = 0, idx_3 = 1;
 
-    buttons = (unsigned char*)malloc(DEFAULT_PTR_MAP_SIZE);
-    if (!buttons)
-    {
-        return;
-    }
-    n_buttons = XGetPointerMapping(QX11Info::display(), buttons, DEFAULT_PTR_MAP_SIZE);
-    if (n_buttons > DEFAULT_PTR_MAP_SIZE)
-    {
-        more_buttons = (unsigned char*)realloc(buttons, n_buttons);
-        if (!more_buttons)
-        {
+    if (auto x11NativeInterface = qGuiApp->nativeInterface<QNativeInterface::QX11Application>()) {
+        if (Display* dpy = x11NativeInterface->display()) {
+            buttons = (unsigned char*)malloc(DEFAULT_PTR_MAP_SIZE);
+            if (!buttons)
+            {
+                return;
+            }
+            n_buttons = XGetPointerMapping(dpy, buttons, DEFAULT_PTR_MAP_SIZE);
+            if (n_buttons > DEFAULT_PTR_MAP_SIZE)
+            {
+                more_buttons = (unsigned char*)realloc(buttons, n_buttons);
+                if (!more_buttons)
+                {
+                    free(buttons);
+                    return;
+                }
+                buttons = more_buttons;
+                n_buttons = XGetPointerMapping(dpy, buttons, n_buttons);
+            }
+
+            for (i = 0; i < n_buttons; i++)
+            {
+                if (buttons[i] == 1)
+                    idx_1 = i;
+                else if (buttons[i] == ((n_buttons < 3) ? 2 : 3))
+                    idx_3 = i;
+            }
+
+            if ((mouse_left_handed && idx_1 < idx_3) ||
+                (!mouse_left_handed && idx_1 > idx_3))
+            {
+                buttons[idx_1] = ((n_buttons < 3) ? 2 : 3);
+                buttons[idx_3] = 1;
+                XSetPointerMapping(dpy, buttons, n_buttons);
+            }
             free(buttons);
-            return;
         }
-        buttons = more_buttons;
-        n_buttons = XGetPointerMapping(QX11Info::display(), buttons, n_buttons);
     }
-
-    for (i = 0; i < n_buttons; i++)
-    {
-        if (buttons[i] == 1)
-            idx_1 = i;
-        else if (buttons[i] == ((n_buttons < 3) ? 2 : 3))
-            idx_3 = i;
-    }
-
-    if ((mouse_left_handed && idx_1 < idx_3) ||
-        (!mouse_left_handed && idx_1 > idx_3))
-    {
-        buttons[idx_1] = ((n_buttons < 3) ? 2 : 3);
-        buttons[idx_3] = 1;
-        XSetPointerMapping(QX11Info::display(), buttons, n_buttons);
-    }
-    free(buttons);
 }
 
 bool SessionApplication::updateDBusEnvironment()
