@@ -32,6 +32,16 @@
         <source>Window manager to use.</source>
         <translation>Gestionnaire de fenêtre à utiliser.</translation>
     </message>
+    <message>
+        <location filename="../src/sessionapplication.cpp" line="83"/>
+        <source>DBus Environment</source>
+        <translation>Environnement DBus</translation>
+    </message>
+    <message>
+        <location filename="../src/sessionapplication.cpp" line="84"/>
+        <source>The DBus Activation Environment wasn&apos;t updated. Some apps might not work properly</source>
+        <translation>L&apos;environnement d&apos;activation de DBus n&apos;a pas été mis à jour. Certaines applications peuvent ne pas fonctionner correctement</translation>
+    </message>
 </context>
 <context>
     <name>WmSelectDialog</name>
